@@ -32,11 +32,11 @@ def serialize_csv(fieldnames, jsons):
     csv_output.close()
     return csv_str
 
-def save_csv(name, text):
+def save_csv(name, text, encoding='utf8'):
     """
     Write text to file
     """
-    with open(name, "a") as csv_file:
+    with open(name, "a", encoding=encoding) as csv_file:
         csv_file.write(text)
 
 
